# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-06-10 13:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Question',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('question', models.CharField(max_length=255, unique=True, verbose_name='Question')),
                ('answer', models.TextField(max_length=10000, verbose_name='Answer')),
            ],
            options={
                'verbose_name': 'Frequent asked question',
                'verbose_name_plural': 'Frequently asked questions',
            },
        ),
    ]
